@@ -31,6 +31,7 @@ import glob
 import random
 import copy
 import socket
+import json
 import logging
 from xml.dom import minidom, Node
 import yaml
@@ -272,9 +273,9 @@ class SitesInfo:
 
    def readSitesInfoFile(self,
                          sitesInfoPath):
-      sitePattern     = re.compile('(\s*\[)([^\s]*)(]\s*)')
-      keyValuePattern = re.compile('( *)(\w*)( *= *)(.*[^\s$])( *)')
-      commentPattern  = re.compile('\s*#.*')
+      sitePattern     = re.compile(r'(\s*\[)([^\s]*)(]\s*)')
+      keyValuePattern = re.compile(r'( *)(\w*)( *= *)(.*[^\s$])( *)')
+      commentPattern  = re.compile(r'\s*#.*')
       siteName        = ""
 
       if os.path.exists(sitesInfoPath):
@@ -336,7 +337,8 @@ class SitesInfo:
                                                 'pegasusTemplates':[],
                                                 'tapisSite':'',
                                                 'executionMode':'block',
-                                                'fileMover':''
+                                                'fileMover':'',
+                                                'timePaths':["/usr/bin/time","/bin/time","/usr/local/bin/time"]
                                                }
                      elif keyValuePattern.match(record):
                         key,value = keyValuePattern.match(record).group(2,4)
@@ -351,23 +353,30 @@ class SitesInfo:
                               self.sites[siteName][key] = int(value)
                            elif isinstance(self.sites[siteName][key],dict):
                               try:
-                                 sampleKey   = self.sites[siteName][key].keys()[0]
+                                 sampleKey   = list(self.sites[siteName][key].keys())[0]
                                  sampleValue = self.sites[siteName][key][sampleKey]
                               except:
-                                 sampleKey   = "key"
-                                 sampleValue = "value"
-                              self.sites[siteName][key] = {}
-                              for e in value.split(','):
-                                 dictKey,dictValue = e.split(':')
-                                 if isinstance(sampleKey,int):
-                                    dictKey = int(dictKey)
-                                 if   isinstance(sampleValue,int):
-                                    dictValue = int(dictValue)
-                                 elif isinstance(sampleValue,float):
-                                    dictValue = float(dictValue)
-                                 elif isinstance(sampleValue,bool):
-                                    dictValue = bool(dictValue.lower() == 'true')
-                                 self.sites[siteName][key][dictKey] = dictValue
+                                 try:
+                                    self.sites[siteName][key] = json.loads(value)
+                                 except:
+                                    self.sites[siteName][key] = {}
+                                    sampleKey   = "key"
+                                    sampleValue = "value"
+                              else:
+                                 self.sites[siteName][key] = {}
+               
+                              if not self.sites[siteName][key]:
+                                 for e in value.split(','):
+                                    dictKey,dictValue = e.split(':')
+                                    if isinstance(sampleKey,int):
+                                       dictKey = int(dictKey)
+                                    if   isinstance(sampleValue,int):
+                                       dictValue = int(dictValue)
+                                    elif isinstance(sampleValue,float):
+                                       dictValue = float(dictValue)
+                                    elif isinstance(sampleValue,bool):
+                                       dictValue = bool(dictValue.lower() == 'true')
+                                    self.sites[siteName][key][dictKey] = dictValue
                            else:
                               self.sites[siteName][key] = value
                         else:
@@ -1087,6 +1096,7 @@ class SitesInfo:
       siteInfo['tapisSite']                        = ""
       siteInfo['executionMode']                    = 'block'
       siteInfo['fileMover']                        = ""
+      siteInfo['timePaths']                        = ["/bin/time","/usr/bin/time","/usr/local/bin/time"]
 
       return(siteInfo)
 
@@ -1145,6 +1155,7 @@ class SitesInfo:
       siteInfo['tapisSite']                        = site['tapisSite']
       siteInfo['executionMode']                    = site['executionMode']
       siteInfo['fileMover']                        = site['fileMover']
+      siteInfo['timePaths']                        = site['timePaths']
 
       return(siteInfo)
 
