@@ -38,7 +38,8 @@ from hubzero.submit.LogMessage             import getLogIDMessage as getLogMessa
 from hubzero.submit.JobStatistic           import JobStatistic
 from hubzero.submit.JobOutput              import JobOutput
 from hubzero.submit.VenueMechanismCore     import VenueMechanismCore
-from hubzero.submit.RemoteBatchTAPIS       import RemoteBatchTAPIS
+from hubzero.submit.RemoteBatchTAPIS2      import RemoteBatchTAPIS2
+from hubzero.submit.RemoteBatchTAPIS3      import RemoteBatchTAPIS3
 from hubzero.submit.RemoteBatchBOINC       import RemoteBatchBOINC
 from hubzero.submit.RemoteBatchCONDOR      import RemoteBatchCONDOR
 from hubzero.submit.RemoteBatchFACTORY     import RemoteBatchFACTORY
@@ -87,7 +88,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                 isMultiCoreRequest,
                 disableJobMonitoring,
                 siteInfo,
-                tapisSiteInfo,
+                tapis2SiteInfo,
+                tapis3SiteInfo,
                 fileMoverInfo,
                 toolFilesInfo,
                 dockerImageInfo,
@@ -106,7 +108,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                 pegasusHome):
       VenueMechanismCore.__init__(self,session,hubUserName,hubUserId,submitterClass,distributorPid,
                                        timeHistoryLogs,disableJobMonitoring,
-                                       siteInfo,tapisSiteInfo,fileMoverInfo,
+                                       siteInfo,tapis2SiteInfo,tapis3SiteInfo,fileMoverInfo,
                                        toolFilesInfo,dockerImageInfo,submissionScriptsInfo,managerInfo,
                                        remoteMonitors,isMultiCoreRequest,nCpus,nNodes,ppn,event)
 
@@ -121,7 +123,7 @@ class VenueMechanismSsh(VenueMechanismCore):
       else:
          self.preStageJobInput              = ""
          self.copyJobInput                  = ""
-      remoteScriptsDirectory = siteInfo['remoteBinDirectory'].replace('$','\$')
+      remoteScriptsDirectory = siteInfo['remoteBinDirectory'].replace('$',r'\$')
       self.receiveInput                     = os.path.join(remoteScriptsDirectory,batchCommands['receiveInput'])
       self.submitBatchJob                   = os.path.join(remoteScriptsDirectory,batchCommands['submitBatchJob'])
       self.postProcessJob                   = os.path.join(remoteScriptsDirectory,batchCommands['postProcessJob'])
@@ -177,7 +179,7 @@ class VenueMechanismSsh(VenueMechanismCore):
          self.arguments                     = ""
          for argument in arguments:
             if ' ' in argument:
-               self.arguments              += "%s " % (argument.replace('\\ ',' ').replace(' ','\ '))
+               self.arguments              += "%s " % (argument.replace('\\ ',' ').replace(' ',r'\ '))
             else:
                self.arguments              += "%s " % (argument)
       else:
@@ -532,7 +534,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                else:
                   appScriptName = ""
                   appScript     = ""
-                  remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
+                  remoteScratchDirectory = self.scratchDirectory.replace('$',r'\$')
                   self.remoteBatch = RemoteWorkflowPEGASUS(self.hubUserName,self.hubUserId,self.submitterClass,
                                                            self.session,self.instanceToken,self.wsJobId,
                                                            self.runName,self.localJobId,self.instanceId,
@@ -560,7 +562,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                            self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,
                                                            self.managerInfo,self.timeHistoryLogs)
                appScriptName,appScript,appScriptExecutable = self.remoteAppScript.buildAppScript()
-               remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
+               remoteScratchDirectory = self.scratchDirectory.replace('$',r'\$')
                self.remoteBatch = RemoteBatchPEGASUS(self.hubUserName,self.hubUserId,self.submitterClass,
                                                      self.session,self.instanceToken,self.wsJobId,
                                                      self.runName,self.localJobId,self.instanceId,
@@ -594,14 +596,31 @@ class VenueMechanismSsh(VenueMechanismCore):
                      self._writeToStderr(message + "\n")
                      if not exitCode:
                         exitCode = 10
-         elif self.remoteBatchSystem == 'TAPIS':
+         elif self.remoteBatchSystem == 'TAPIS2':
             appScriptName       = ""
             appScript           = ""
             appScriptExecutable = False
-            self.remoteBatch = RemoteBatchTAPIS(self.session,self.instanceToken,self.wsJobId,
-                                                self.localJobId,self.instanceId,
-                                                self.tapisSiteInfo,self.submissionScriptsInfo,
-                                                self.nNodes,self.ppn,self.wallTime)
+            self.remoteBatch = RemoteBatchTAPIS2(self.session,self.instanceToken,self.wsJobId,
+                                                 self.runName,self.localJobId,self.instanceId,
+                                                 self.tapis2SiteInfo,self.submissionScriptsInfo,
+                                                 self.nNodes,self.ppn,self.wallTime)
+            batchScriptName,batchScript = self.remoteBatch.getBatchTapisFile()
+            batchScriptExecutable       = False
+            batchLogName                = ""
+            nodeFileName                = ""
+            nodeList                    = []
+            toolInputTemplateFileName   = ""
+            toolInputTemplate           = ""
+            toolOutputTemplateFileName  = ""
+            toolOutputTemplate          = ""
+         elif self.remoteBatchSystem == 'TAPIS3':
+            appScriptName       = ""
+            appScript           = ""
+            appScriptExecutable = False
+            self.remoteBatch = RemoteBatchTAPIS3(self.session,self.instanceToken,self.wsJobId,
+                                                 self.runName,self.localJobId,self.instanceId,
+                                                 self.tapis3SiteInfo,self.submissionScriptsInfo,
+                                                 self.nNodes,self.ppn,self.wallTime)
             batchScriptName,batchScript = self.remoteBatch.getBatchTapisFile()
             batchScriptExecutable       = False
             batchLogName                = ""
@@ -793,11 +812,11 @@ class VenueMechanismSsh(VenueMechanismCore):
       self.jobStatistics[self.jobIndex]['venue'] = self.venue
 
       if   not self.sharedUserSpace and self.stageFiles:
-         remoteWorkingDirectory = self.workingDirectory.replace('$','\$')
-         remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
+         remoteWorkingDirectory = self.workingDirectory.replace('$',r'\$')
+         remoteScratchDirectory = self.scratchDirectory.replace('$',r'\$')
 
          if self.sshBaseCommand != "":
-            stageInTarPath = os.path.join(self.instanceDirectory,self.stageInTarFile).replace(' ','\ ')
+            stageInTarPath = os.path.join(self.instanceDirectory,self.stageInTarFile).replace(' ',r'\ ')
             command = "cat " + stageInTarPath + " | " + self.sshBaseCommand + \
                                                   " \"" + self.receiveInput + " " + \
                                                      remoteWorkingDirectory + " " + \
@@ -815,7 +834,7 @@ class VenueMechanismSsh(VenueMechanismCore):
             self.jobStatistics[self.jobIndex]['exitCode'] = 11
       elif self.sharedUserSpace and self.stageFiles:
          remoteWorkingDirectory = self.instanceDirectory
-         remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
+         remoteScratchDirectory = self.scratchDirectory.replace('$',r'\$')
 
          if self.sshBaseCommand != "":
             command = self.sshBaseCommand + " \"" + self.receiveInput + " " + \
@@ -876,8 +895,8 @@ class VenueMechanismSsh(VenueMechanismCore):
 
       if   self.remoteBatchSystem == 'SCRIPT':
          if self.stageFiles:
-            remoteWorkingDirectory = self.workingDirectory.replace('$','\$')
-            remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
+            remoteWorkingDirectory = self.workingDirectory.replace('$',r'\$')
+            remoteScratchDirectory = self.scratchDirectory.replace('$',r'\$')
             commandArgs = []
             commandArgs.append(self.submitBatchJob)
             commandArgs.append(remoteWorkingDirectory)
@@ -916,8 +935,8 @@ class VenueMechanismSsh(VenueMechanismCore):
             self.jobStatistics[self.jobIndex]['exitCode'] = exitStatus
       elif self.remoteBatchSystem == 'BGSCRIPT':
          if self.stageFiles:
-            remoteWorkingDirectory = self.workingDirectory.replace('$','\$')
-            remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
+            remoteWorkingDirectory = self.workingDirectory.replace('$',r'\$')
+            remoteScratchDirectory = self.scratchDirectory.replace('$',r'\$')
             commandArgs = []
             commandArgs.append(self.submitBatchJob)
             commandArgs.append(remoteWorkingDirectory)
@@ -962,8 +981,8 @@ class VenueMechanismSsh(VenueMechanismCore):
             if self.sharedUserSpace:
                remoteWorkingDirectory = self.instanceDirectory
             else:
-               remoteWorkingDirectory = self.workingDirectory.replace('$','\$')
-            remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
+               remoteWorkingDirectory = self.workingDirectory.replace('$',r'\$')
+            remoteScratchDirectory = self.scratchDirectory.replace('$',r'\$')
             commandArgs = []
             commandArgs.append(self.submitBatchJob)
             commandArgs.append(remoteWorkingDirectory)
@@ -1021,8 +1040,8 @@ class VenueMechanismSsh(VenueMechanismCore):
             if self.sharedUserSpace:
                remoteWorkingDirectory = self.instanceDirectory
             else:
-               remoteWorkingDirectory = self.workingDirectory.replace('$','\$')
-            remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
+               remoteWorkingDirectory = self.workingDirectory.replace('$',r'\$')
+            remoteScratchDirectory = self.scratchDirectory.replace('$',r'\$')
             commandArgs = []
             commandArgs.append(self.submitBatchJob)
             commandArgs.append(remoteWorkingDirectory)
@@ -1123,10 +1142,10 @@ class VenueMechanismSsh(VenueMechanismCore):
             if self.jobSubmitted:
                if (self.isParametric and self.instanceId == "0") or not self.isParametric:
                   if not self.sharedUserSpace:
-                     remoteWorkingDirectory = self.workingDirectory.replace('$','\$')
+                     remoteWorkingDirectory = self.workingDirectory.replace('$',r'\$')
                   else:
                      remoteWorkingDirectory = self.instanceDirectory
-                  remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
+                  remoteScratchDirectory = self.scratchDirectory.replace('$',r'\$')
                   command = self.sshBaseCommand + " \"" + self.postProcessJob + " " + \
                                                           remoteWorkingDirectory + " " + \
                                                           remoteScratchDirectory + " " + \
@@ -1144,7 +1163,7 @@ class VenueMechanismSsh(VenueMechanismCore):
       exitStatus = 0
 
       if   not self.sharedUserSpace and self.stageFiles:
-         remoteWorkingDirectory = self.workingDirectory.replace('$','\$')
+         remoteWorkingDirectory = self.workingDirectory.replace('$',r'\$')
          if self.jobSubmitted:
             if self.instanceId != "0":
                stageOutTarFile = "%s_%s_output.tar" % (self.localJobId,self.instanceId)
@@ -1154,7 +1173,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                   remoteWorkingDirectory + " " + \
                                                          stageOutTarFile + "\"" + \
                                             " | tar xzmf - --ignore-case --exclude '*hub-proxy.*' -C " + \
-                                                  self.instanceDirectory.replace(' ','\ ')
+                                                  self.instanceDirectory.replace(' ',r'\ ')
             self.logger.log(logging.INFO,getLogMessage("command = " + command))
             exitStatus,stdOutput,stdError = self.executeSSHCommand(command,self.tunnelDesignator)
             self.logger.log(logging.INFO,getLogMessage(stdOutput))
@@ -1204,10 +1223,10 @@ class VenueMechanismSsh(VenueMechanismCore):
             if os.path.isfile(stageOutTarFile):
                if stageOutTarFile.endswith('.gz'):
                   command = "tar xzmf " + stageOutTarFile + \
-                                      " --ignore-case --exclude '*hub-proxy.*' -C " + self.instanceDirectory.replace(' ','\ ')
+                                      " --ignore-case --exclude '*hub-proxy.*' -C " + self.instanceDirectory.replace(' ',r'\ ')
                else:
                   command = "tar xmf " + stageOutTarFile + \
-                                     " --ignore-case --exclude '*hub-proxy.*' -C " + self.instanceDirectory.replace(' ','\ ')
+                                     " --ignore-case --exclude '*hub-proxy.*' -C " + self.instanceDirectory.replace(' ',r'\ ')
                self.logger.log(logging.INFO,getLogMessage("command = " + command))
                exitStatus,stdOutput,stdError = self.executeCommand(command)
                if exitStatus == 0:
@@ -1260,10 +1279,10 @@ class VenueMechanismSsh(VenueMechanismCore):
             if self.jobSubmitted:
                if (self.isParametric and self.instanceId == "0") or not self.isParametric:
                   if not self.sharedUserSpace:
-                     remoteWorkingDirectory = self.workingDirectory.replace('$','\$')
+                     remoteWorkingDirectory = self.workingDirectory.replace('$',r'\$')
                   else:
                      remoteWorkingDirectory = self.instanceDirectory
-                  remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
+                  remoteScratchDirectory = self.scratchDirectory.replace('$',r'\$')
 
                   if self.isParametric:
                      self.jobOutput.getPegasusStdTimeFiles(self.instanceDirectory,
@@ -1291,8 +1310,8 @@ class VenueMechanismSsh(VenueMechanismCore):
             self.cleanupPegasusFiles()
          else:
             if   not self.sharedUserSpace and self.stageFiles:
-               remoteWorkingDirectory = self.workingDirectory.replace('$','\$')
-               remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
+               remoteWorkingDirectory = self.workingDirectory.replace('$',r'\$')
+               remoteScratchDirectory = self.scratchDirectory.replace('$',r'\$')
                if self.jobSubmitted:
                   command = self.sshBaseCommand + " \"" + self.cleanupJob + " " + \
                                                    remoteWorkingDirectory + " " + \
